==> connectivity-jenkins-client-1.4-sources.jar: org/mule/tools/connectivity/jenkins/client/xmlBuilder/DevelopClassicPullRequestBuilderXmlConfigBuilder.java <==
package org.mule.tools.connectivity.jenkins.client.xmlBuilder;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.text.StrSubstitutor;
import org.mule.tools.connectivity.jenkins.client.ConnectorConfiguration;
import org.mule.tools.connectivity.jenkins.client.models.buildwrappers.Bindings;
import org.mule.tools.connectivity.jenkins.client.models.buildwrappers.StringBinding;
import org.mule.tools.connectivity.jenkins.client.models.buildwrappers.UsernamePasswordMultiBinding;
import org.mule.tools.connectivity.jenkins.client.models.properties.JobBlocker;
import org.mule.tools.connectivity.jenkins.client.models.publishers.JunitResultArchiver;
import org.mule.tools.connectivity.jenkins.client.models.triggers.PullRequestBuilderTrigger;
import org.mule.tools.connectivity.jenkins.client.util.GithubSSHURLParser;
import org.mule.tools.connectivity.jenkins.client.models.scm.GithubSCMPRBuilder;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static org.mule.tools.connectivity.jenkins.client.util.StepBuilder.*;
import static org.mule.tools.connectivity.jenkins.client.JobConstants.*;


/**
 * Created by estebanwasinger on 10/5/15.
 */
public class DevelopClassicPullRequestBuilderXmlConfigBuilder extends BasicXmlConfigBuilder{

    public static String buildXmlConfig(final ConnectorConfiguration connector, final String mavenGoal){

        String xml = getResourceAsString(BASIC_TEMPLATE_XML);

        Map<String, String> valuesMap = new HashMap<>();
        valuesMap.put(GITHUB_CONFIG, new GithubSCMPRBuilder(connector.getGitHubUrl(),"${sha1}").getXmlConfig());
        valuesMap.put(GITHUB_HTTP_URL, GithubSSHURLParser.toHttpsURL(connector.getGitHubUrl()));
        valuesMap.put(UNZIP_MULE_SHELL_STEP, "");
        valuesMap.put(CONNECTOR_STEPS, connector.getSteps());
        valuesMap.put(CTF_BUILD_STEP, cleanStep().getXmlConfig() + getDevelopBuildSteps(connector, mavenGoal) + newSonarPRBuilderStep(connector).getXmlConfig());
        valuesMap.put(MAILER, connector.getMailer().getXmlConfig());
        valuesMap.put(TRIGGERS, new PullRequestBuilderTrigger(connector.getName()+"-develop-PR-BUILDER").getXmlConfig());
        valuesMap.put(JDK_VERSION, connector.getJceEnabled() ? JDK_8_JCE : JDK_8);
        valuesMap.put(ENABLE_JCE_STEPS, connector.getJceEnabled() ? getEnableJceSteps().getXmlConfig() : "");
        valuesMap.put(MULE_CONF_FOR_JCE_STEPS, "");
        valuesMap.put(PROPERTIES, connector.getParallelBuilds() ? StringUtils.EMPTY : new JobBlocker(connector.getName() + ".*").getXmlConfig());
        valuesMap.put(BUILD_WRAPPERS, new Bindings(
                new UsernamePasswordMultiBinding("7709cb6e-a949-4033-950f-cd1bb38b3b65", "SONAR_USERNAME", "SONAR_PASSWORD"),
                new StringBinding("d8a25f4f-4481-46e6-bbc0-6d49a42806b9", "SONAR_GITHUB_OAUTH")
        ).getXmlConfig());
        valuesMap.put(PUBLISHERS, new JunitResultArchiver().getXmlConfig());

        StrSubstitutor sub = new StrSubstitutor(valuesMap);
        return sub.replace(xml);
    }

    private static String getDevelopBuildSteps(final ConnectorConfiguration connector, final String mavenGoal) {
        List<String> stepList = new ArrayList<>();
        if (connector.getActiveConfigs() != null && !connector.getActiveConfigs().isEmpty()) {
            connector.getActiveConfigs().forEach(config -> stepList.add(classicDevelopBuildStep(connector, mavenGoal, config).getXmlConfig()));
        } else {
            stepList.add(classicDevelopBuildStep(connector, mavenGoal).getXmlConfig());
        }

        return stepList.stream().reduce("", String::concat);
    }

}

==> connectivity-jenkins-client-1.7-sources.jar: org/mule/tools/connectivity/jenkins/client/xmlBuilder/DevelopClassicPullRequestBuilderXmlConfigBuilder.java <==
package org.mule.tools.connectivity.jenkins.client.xmlBuilder;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang3.text.StrSubstitutor;
import org.mule.tools.connectivity.jenkins.client.ConnectorConfiguration;
import org.mule.tools.connectivity.jenkins.client.models.buildwrappers.Bindings;
import org.mule.tools.connectivity.jenkins.client.models.buildwrappers.StringBinding;
import org.mule.tools.connectivity.jenkins.client.models.buildwrappers.UsernamePasswordMultiBinding;
import org.mule.tools.connectivity.jenkins.client.models.properties.JobBlocker;
import org.mule.tools.connectivity.jenkins.client.models.publishers.JunitResultArchiver;
import org.mule.tools.connectivity.jenkins.client.models.triggers.PullRequestBuilderTrigger;
import org.mule.tools.connectivity.jenkins.client.util.GithubSSHURLParser;
import org.mule.tools.connectivity.jenkins.client.models.scm.GithubSCMPRBuilder;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static org.mule.tools.connectivity.jenkins.client.util.StepBuilder.*;
import static org.mule.tools.connectivity.jenkins.client.JobConstants.*;


/**
 * Created by estebanwasinger on 10/5/15.
 */
public class DevelopClassicPullRequestBuilderXmlConfigBuilder extends BasicXmlConfigBuilder{

    public static String buildXmlConfig(final ConnectorConfiguration connector) {

        String xml = getResourceAsString(BASIC_TEMPLATE_XML);

        Map<String, String> valuesMap = new HashMap<>();
        valuesMap.put(GITHUB_CONFIG, new GithubSCMPRBuilder(connector.getGitHubUrl(),"${sha1}").getXmlConfig());
        valuesMap.put(GITHUB_HTTP_URL, GithubSSHURLParser.toHttpsURL(connector.getGitHubUrl()));
        valuesMap.put(UNZIP_MULE_SHELL_STEP, "");
        valuesMap.put(CONNECTOR_STEPS, connector.getSteps());
        valuesMap.put(CTF_BUILD_STEP, cleanStep().getXmlConfig() + getDevelopBuildSteps(connector) + newSonarPRBuilderStep(connector).getXmlConfig());
        valuesMap.put(MAILER, connector.getMailer().getXmlConfig());
        valuesMap.put(TRIGGERS, new PullRequestBuilderTrigger(connector.getName()+"-develop-PR-BUILDER").getXmlConfig());
        valuesMap.put(JDK_VERSION, connector.getJceEnabled() ? JDK_8_JCE : JDK_8);
        valuesMap.put(ENABLE_JCE_STEPS, connector.getJceEnabled() ? getEnableJceSteps().getXmlConfig() : "");
        valuesMap.put(MULE_CONF_FOR_JCE_STEPS, "");
        valuesMap.put(PROPERTIES, connector.getParallelBuilds() ? StringUtils.EMPTY : new JobBlocker(connector.getName() + ".*").getXmlConfig());
        valuesMap.put(BUILD_WRAPPERS, new Bindings(
                new UsernamePasswordMultiBinding("7709cb6e-a949-4033-950f-cd1bb38b3b65", "SONAR_USERNAME", "SONAR_PASSWORD"),
                new StringBinding("d8a25f4f-4481-46e6-bbc0-6d49a42806b9", "SONAR_GITHUB_OAUTH")
        ).getXmlConfig());
        valuesMap.put(PUBLISHERS, new JunitResultArchiver().getXmlConfig());

        StrSubstitutor sub = new StrSubstitutor(valuesMap);
        return sub.replace(xml);
    }

    private static String getDevelopBuildSteps(final ConnectorConfiguration connector) {
        List<String> stepList = new ArrayList<>();
        if (connector.getActiveConfigs() != null && !connector.getActiveConfigs().isEmpty()) {
            connector.getActiveConfigs().forEach(config -> stepList.add(classicDevelopBuildStep(connector, config).getXmlConfig()));
        } else {
            stepList.add(classicDevelopBuildStep(connector).getXmlConfig());
        }

        return stepList.stream().reduce("", String::concat);
    }

}
